@@ -1,24 +1,14 @@
-import xml.etree.ElementTree as ET
 import os
-import glob
+import xml.etree.ElementTree as ET
 
-from firstimpression.api.request import request_json
-from firstimpression.constants import APIS, DUTCH_INDEX, LOCAL_INTEGRATED_FOLDER, TEMP_FOLDER
-from firstimpression.file import check_too_old, download_install_media, update_directories_api, write_root_to_xml_files
-from firstimpression.scala import variables, Log
+from firstimpression.api.request import give_error_message, request_json
+from firstimpression.constants import APIS
+from firstimpression.file import (check_too_old, create_directories,
+                                  purge_directories)
+from firstimpression.placeholder import update_placeholders
+from firstimpression.scala import ScalaPlayer
 from firstimpression.text import remove_emoji
-from firstimpression.time import change_language, parse_string_to_string
-
-##################################################################################################
-# LOGGING
-##################################################################################################
-
-script = 'Twitter'
-
-info = Log('INFO', script)
-debug = Log('DEBUG', script)
-warn = Log('WARN', script)
-error = Log('ERROR', script)
+from firstimpression.time import parse_string_to_string
 
 ##################################################################################################
 # CONSTANTS
@@ -32,19 +22,29 @@ DATETIME_FORMAT_NEW = '%d %B %Y'
 URL = 'https://fi-api.io/twitter_post/'
 
 XML_FILENAME = 'twitter.xml'
-XML_FILENAME_CONTENT = 'twitter*.xml'
-XML_TEMP_PATH = os.path.join(TEMP_FOLDER, NAME, XML_FILENAME)
-XML_LOCAL_PATH = os.path.join(LOCAL_INTEGRATED_FOLDER, NAME, XML_FILENAME_CONTENT)
 
 MAX_FILE_AGE = 60 * 5
 
+##################################################################################################
+# Scala Player
+##################################################################################################
+
+scala = ScalaPlayer(NAME)
+
+XML_TEMP_PATH = os.path.join(scala.temp_folder, XML_FILENAME)
+
 ##################################################################################################
 # MAIN FUNCTIONS API
 ##################################################################################################
 
-def run_api(api_key, max_items):
-    debug.log('folder name: {}'.format(NAME))
-    debug.log('file path temp: {} - local: {}'.format(XML_TEMP_PATH, XML_LOCAL_PATH))
+
+def run_api():
+
+    api_key = scala.variables['api_key']
+    max_items = scala.variables['max_items']
+
+    scala.debug('folder name: {}'.format(NAME))
+    scala.debug('file path temp: {}'.format(XML_TEMP_PATH))
 
     headers = {
         'Authorization': 'Token {}'.format(api_key)
@@ -54,45 +54,44 @@ def run_api(api_key, max_items):
         'number_of_posts': max_items
     }
 
-    update_directories_api(NAME)
-    change_language(DUTCH_INDEX)
+    create_directories([scala.temp_folder, scala.content_folder])
+    purge_directories([scala.temp_folder, scala.content_folder], max_days=1)
+    update_placeholders()
 
     if check_too_old(XML_TEMP_PATH, MAX_FILE_AGE):
         response_json, is_error = request_json(URL, headers, params, False)
 
         if is_error:
+            message = give_error_message(response_json)
             if response_json['type'] == 'ERROR':
-                error.log('request {} -> {}'.format(response_json['reason'], response_json['message']))
+                scala.error(message)
             elif response_json['type'] == 'WARN':
-                warn.log('request {} -> {}'.format(response_json['reason'], response_json['message']))
-            exit()
+                scala.warn(message)
+
+            raise SystemExit
 
         root = ET.Element("root")
 
         for post in response_json:
             root.append(parse_post(post))
-        
-        write_root_to_xml_files(root, XML_TEMP_PATH, NAME)
+
+        temp_path = scala.download_root_temp(root, XML_FILENAME)
+        scala.install_content(temp_path)
     else:
-        debug.log('File not old enough to update')
+        scala.debug('File not old enough to update')
+
 
 def check_api():
-    svars = variables()
+    svars = scala.variables
 
-    file_path = sorted(glob.glob(XML_LOCAL_PATH))
+    file_path = scala.find_content(
+        'Content://{}/{}'.format(NAME, XML_FILENAME))
 
-    if len(file_path) > 0:
-        file_path = file_path[-1]
-        debug.log('glob filepath: {}'.format(file_path))
-
-        if check_too_old(file_path, MAX_FILE_AGE*2):
-            svars['skipscript'] = True
-            info.log('file too old')
-        else:
-            svars['skipscript'] = False
-    else:
-        warn.log('File does not exists')
+    if check_too_old(file_path, MAX_FILE_AGE * 2):
         svars['skipscript'] = True
+        scala.debug('file too old')
+    else:
+        svars['skipscript'] = False
 
 
 ##################################################################################################
@@ -107,19 +106,23 @@ def check_api():
 def get_likes(post):
     return post.get('likes', 0)
 
+
 def get_message(post):
     return post.get('message', '')
 
+
 def get_creation_date(post):
     return post.get('created_at', '')
 
+
 def get_image(post):
     url = post.get('image', None)
     if url is None:
-        debug.log('No image found using placeholder instead')
+        scala.debug('No image found using placeholder instead')
         return 'Content:\\placeholders\\img.png'
     else:
-        return download_install_media(url, TEMP_FOLDER, NAME)
+        temp_path = scala.download_media_temp(url)
+        return scala.install_content(temp_path)
 
 
 ##################################################################################################
@@ -130,6 +133,7 @@ def parse_post(post):
     item = ET.Element("item")
     ET.SubElement(item, "likes").text = str(get_likes(post))
     ET.SubElement(item, "message").text = remove_emoji(get_message(post))
-    ET.SubElement(item, "created_time").text = parse_string_to_string(get_creation_date(post), DATETIME_FORMAT, DATETIME_FORMAT_NEW)
+    ET.SubElement(item, "created_time").text = parse_string_to_string(
+        get_creation_date(post), DATETIME_FORMAT, DATETIME_FORMAT_NEW)
     ET.SubElement(item, "image").text = get_image(post)
-    return item
\ No newline at end of file
+    return item
